# start xsunpinyin
# vim: set sts=4 expandtab:

if [ "$IM_CONFIG_PHASE" = 2 ]; then
# start xsunpinyin daemon
/usr/bin/xsunpinyin -d
fi

if [ "$IM_CONFIG_PHASE" = 1 ]; then
# set variables for the plain XIM
XMODIFIERS=@im=xsunpinyin
GTK_IM_MODULE=xim
QT_IM_MODULE=xim
CLUTTER_IM_MODULE=xim
fi
