# start thai
# vim: set sts=4 expandtab:

if [ "$IM_CONFIG_PHASE" = 1 ]; then
# set variables for the plain XIM
XMODIFIERS=@im=BasicCheck

# Let's assume all required modules are installed
GTK_IM_MODULE=thai-libthai

# No IM modules for Qt and Clutter for now
QT_IM_MODULE=xim
CLUTTER_IM_MODULE=xim


fi
