# start fcitx
# vim: set sts=4 expandtab:

if [ "$IM_CONFIG_PHASE" = 2 ]; then
    # start fcitx daemon
    /usr/bin/fcitx -d 2> /dev/null
fi


if [ "$IM_CONFIG_PHASE" = 1 ]; then
# set variables for the plain XIM
XMODIFIERS=@im=fcitx

# Let's assume all required modules are installed
GTK_IM_MODULE=fcitx
QT_IM_MODULE=fcitx
CLUTTER_IM_MODULE=fcitx

fi
