# start gcin
# vim: set sts=4 expandtab:

if [ "$IM_CONFIG_PHASE" = 2 ]; then
# start gcin daemon
/usr/bin/gcin &
fi

if [ "$IM_CONFIG_PHASE" = 1 ]; then
# set variables for the plain XIM
XMODIFIERS=@im=gcin

# Let's assume all required modules are installed
GTK_IM_MODULE=gcin
QT_IM_MODULE=gcin
# gcin has no clutter support
CLUTTER_IM_MODULE=xim


fi
