# start maliit
# vim: set sts=4 expandtab:

if [ "$IM_CONFIG_PHASE" = 2 ]; then
    #start maliit-server
    /usr/bin/maliit-server -software -bypass-wm-hint
fi

if [ "$IM_CONFIG_PHASE" = 1 ]; then
    XIM=none
    GTK_IM_MODULE=meego-im
fi
