# start SCIM
# vim: set sts=4 expandtab:

if [ "$IM_CONFIG_PHASE" = 2 ]; then
# start SCIM daemon
/usr/bin/scim --daemon
fi

if [ "$IM_CONFIG_PHASE" = 1 ]; then
# set variables for the plain XIM
XMODIFIERS=@im=SCIM

# Let's assume all required modules are installed
GTK_IM_MODULE=scim
QT_IM_MODULE=scim
CLUTTER_IM_MODULE=scim

fi
